==> gambit_0.97.0.4.orig.tar.gz: gambit-0.97.0.4/sources/gui/nfgconst.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/gui/Attic/nfgconst.h,v $
// $Date: 2003/09/01 02:31:30 $
// $Revision: 1.13.2.2 $
//
// DESCRIPTION:
// Declaration of menu constants for normal form window
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef NFGCONST_H
#define NFGCONST_H

const int NFG_EDIT_STRATS = 301;
const int NFG_EDIT_CONTINGENCY = 309;
const int NFG_EDIT_GAME = 310;

const int NFG_VIEW_PROFILES = 101;
const int NFG_VIEW_NAVIGATION = 102;
const int NFG_VIEW_OUTCOMES = 103;
const int NFG_VIEW_SUPPORTS = 104;
const int NFG_VIEW_DOMINANCE = 110;
const int NFG_VIEW_PROBABILITIES = 111;
const int NFG_VIEW_VALUES = 112;
const int NFG_VIEW_OUTCOME_LABELS = 120;

const int NFG_FORMAT_DISPLAY = 204;
const int NFG_FORMAT_DISPLAY_DECIMALS = 207;
const int NFG_FORMAT_FONT = 212;
const int NFG_FORMAT_FONT_DATA = 208;
const int NFG_FORMAT_FONT_LABELS = 203;

const int NFG_TOOLS_DOMINANCE = 160;
const int NFG_TOOLS_EQUILIBRIUM = 498;
const int NFG_TOOLS_QRE = 499;

const int NFG_SUPPORT_DUPLICATE = 710;
const int NFG_SUPPORT_DELETE = 711;

const int NFG_PROFILES_NEW = 701;
const int NFG_PROFILES_DUPLICATE = 702;
const int NFG_PROFILES_DELETE = 703;
const int NFG_PROFILES_DELETE_ALL = 706;
const int NFG_PROFILES_PROPERTIES = 704;
const int NFG_PROFILES_REPORT = 705;

#endif // NFGCONST_H

==> gambit_0.97.0.7.orig.tar.gz: gambit-0.97.0.7/sources/gui/nfgconst.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/gui/Attic/nfgconst.h,v $
// $Date: 2003/12/12 21:56:07 $
// $Revision: 1.13.2.3 $
//
// DESCRIPTION:
// Declaration of menu constants for normal form window
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef NFGCONST_H
#define NFGCONST_H

const int NFG_FILE_EXPORT = 800;
const int NFG_FILE_EXPORT_HTML = 801;
const int NFG_FILE_EXPORT_OSBORNE = 802;

const int NFG_EDIT_STRATS = 301;
const int NFG_EDIT_CONTINGENCY = 309;
const int NFG_EDIT_GAME = 310;

const int NFG_VIEW_PROFILES = 101;
const int NFG_VIEW_NAVIGATION = 102;
const int NFG_VIEW_OUTCOMES = 103;
const int NFG_VIEW_SUPPORTS = 104;
const int NFG_VIEW_DOMINANCE = 110;
const int NFG_VIEW_PROBABILITIES = 111;
const int NFG_VIEW_VALUES = 112;
const int NFG_VIEW_OUTCOME_LABELS = 120;

const int NFG_FORMAT_DISPLAY = 204;
const int NFG_FORMAT_DISPLAY_DECIMALS = 207;
const int NFG_FORMAT_FONT = 212;
const int NFG_FORMAT_FONT_DATA = 208;
const int NFG_FORMAT_FONT_LABELS = 203;

const int NFG_TOOLS_DOMINANCE = 160;
const int NFG_TOOLS_EQUILIBRIUM = 498;
const int NFG_TOOLS_QRE = 499;

const int NFG_SUPPORT_DUPLICATE = 710;
const int NFG_SUPPORT_DELETE = 711;

const int NFG_PROFILES_NEW = 701;
const int NFG_PROFILES_DUPLICATE = 702;
const int NFG_PROFILES_DELETE = 703;
const int NFG_PROFILES_DELETE_ALL = 706;
const int NFG_PROFILES_PROPERTIES = 704;
const int NFG_PROFILES_REPORT = 705;

#endif // NFGCONST_H
